@@ -1,8 +1,7 @@
 use regex::Regex;
-use rustc_hash::FxHashMap;
 use serde::{Deserialize, Serialize};
 use swc_atoms::JsWord;
-use swc_common::Mark;
+use swc_common::{collections::AHashMap, Mark};
 use swc_ecma_ast::{EsVersion, Expr};
 
 pub mod terser;
@@ -158,7 +157,7 @@ pub struct CompressOptions {
     /// to remove spans.
     #[serde(skip)]
     #[serde(alias = "global_defs")]
-    pub global_defs: FxHashMap<Box<Expr>, Box<Expr>>,
+    pub global_defs: AHashMap<Box<Expr>, Box<Expr>>,
 
     #[serde(default)]
     #[serde(alias = "hoist_funs")]
